@@ -4,10 +4,12 @@ import os
 from mako.lookup import TemplateLookup
 from pylons.configuration import PylonsConfig
 from pylons.error import handle_mako_error
+from sqlalchemy import engine_from_config
 
 import pysvnmanager.lib.app_globals as app_globals
 import pysvnmanager.lib.helpers
 from pysvnmanager.config.routing import make_map
+from pysvnmanager.model import init_model
 
 def load_environment(global_conf, app_conf):
     """Configure the Pylons environment via the ``pylons.config``
@@ -42,6 +44,26 @@ def load_environment(global_conf, app_conf):
         input_encoding='utf-8', default_filters=['escape'],
         imports=['from webhelpers.html import escape'])
 
+    # Setup the SQLAlchemy database engine
+    if 'sqlalchemy.url' in config:
+        engine = engine_from_config(config, 'sqlalchemy.')
+    else:
+        from sqlalchemy import create_engine
+        engine = create_engine('sqlite:///%(here)s/db/fallback.db' % config)
+
+    init_model(engine)
+
+    # Create database if not exists.
+    if ( engine.url.drivername in ['sqlite'] and
+         not os.path.exists( engine.url.database ) ):
+
+        if not os.path.exists( os.path.dirname( engine.url.database ) ):
+            os.makedirs( os.path.dirname( engine.url.database ) )
+
+        # initialized database here.
+        from pysvnmanager.model.meta import Session, metadata, Base
+        Base.metadata.create_all(bind=Session.bind)
+
     # CONFIGURATION OPTIONS HERE (note: all config options will override
     # any Pylons config options)
     
