@@ -30,6 +30,7 @@ class AuthzController(BaseController):
     requires_auth = True
 
     def __init__(self):
+        c.menu_active = "authz"
         try:
             self.authz = SvnAuthz(cfg.authz_file)
             self.login_as = session.get('user')
@@ -58,9 +59,6 @@ class AuthzController(BaseController):
         super(AuthzController, self).__before__(action)
         if not self.own_reposlist and not self.is_super_user:
             return redirect(url(controller='security', action='failed'))
-        diff = self.authz.differ()
-        if diff:
-            c.global_message = _('Some one maybe you, has modified the svn authz file by hands. Please save once to fix possible config error.') + "<blockquote>" + "<br>".join(diff.splitlines()) + "</blockquote>"
 
     def index(self):
         c.revision = self.authz.version
@@ -68,20 +66,22 @@ class AuthzController(BaseController):
         # used for functional test.
         c.reposlist = self.own_reposlist
         all_avail_users = []
-        all_avail_users.append([_("All users(with anon)"), '*'])
-        all_avail_users.append([_("Known users"), '$authenticated'])
-        all_avail_users.append([_("Anonymous"), '$anonymous'])
+        all_avail_users.append(['*', _("All users(with anon)")])
+        all_avail_users.append(['$authenticated', _("Known users")])
+        all_avail_users.append(['$anonymous', _("Anonymous")])
         for group in self.authz.grouplist:
             i = group.uname
             if i == '*' or i =='$authenticated' or i == '$anonymous':
                 continue
-            all_avail_users.append([_("Group:")+i[1:], i])
+            all_avail_users.append([i, _("Group:")+i[1:]])
         for alias in self.authz.aliaslist:
             i = alias.uname
-            all_avail_users.append([_("Alias:")+i[1:], i])
-        for user in self.authz.userlist:
-            i = user.uname
-            all_avail_users.append([i, i])
+            all_avail_users.append([i, _("Alias:")+i[1:]])
+        for user in self.authz.nice_userlist:
+            if user.nice_name:
+                all_avail_users.append([user.uname, "%s (%s)" % (user.uname, user.nice_name)])
+            else:
+                all_avail_users.append([user.uname, user.uname])
         
         c.all_avail_users = all_avail_users
 
