@@ -25,12 +25,18 @@ from pysvnmanager.model import repos as _repos
 from pysvnmanager.model import hooks as _hooks
 from pylons.i18n import _, ungettext, N_
 
+try:
+    import json
+except ImportError:
+    import simplejson as json
+
 log = logging.getLogger(__name__)
 
 class ReposController(BaseController):
     requires_auth = True
     
     def __init__(self):
+        c.menu_active = "repos"
         try:
             self.authz = SvnAuthz(cfg.authz_file)
             self.login_as = session.get('user')
@@ -60,9 +66,6 @@ class ReposController(BaseController):
         super(ReposController, self).__before__(action)
         if not self.own_reposlist and not self.is_super_user:
             return redirect(url(controller='security', action='failed'))
-        diff = self.authz.differ()
-        if diff:
-            c.global_message = _('Some one maybe you, has modified the svn authz file by hands. Please save once to fix possible config error.') + "<blockquote>" + "<br>".join(diff.splitlines()) + "</blockquote>"
         
     def index(self):
         c.is_super_user = self.is_super_user
@@ -120,15 +123,15 @@ class ReposController(BaseController):
         h = _hooks.Hooks(cfg.repos_root + '/' + reposname)
         msg = ''
         if len(h.applied_plugins) > 0:
-            msg += _("Installed hooks:")
+            msg += "<span class='title'>%s</span>" % _("Installed hooks:")
             msg += "<br>\n"
             num = 0
             
-            msg += "<table class='hidden'>\n"
+            msg += "<table class='list' width='99%'>\n"
             msg += "<tr><th align='left'></th>" + \
-                    "<th align='left'>" + _("Id") + "</th>" + \
+                    "<th align='left' width='20%'>" + _("Id") + "</th>" + \
                     "<th align='left'>" + _("Plugin name") + "</th>" + \
-                    "<th align='left'>" + _("Type") + "</th>" + \
+                    "<th align='left' width='15%'>" + _("Type") + "</th>" + \
                     "</tr>\n"
             for name in h.applied_plugins:
                 msg += "<tr><td width='1' rolspan='2'>"
@@ -139,10 +142,10 @@ class ReposController(BaseController):
                 msg += "<td>" + h.plugins[name].name + "</td>\n"
                 msg += "<td>" + h.plugins[name].get_type() + "</td>\n"
                 msg += "</tr>\n"
-                msg += "<tr><td></td><td colspan='3'>" + h.plugins[name].show_install_info() + "</td></tr>\n"
+                msg += "<tr><td></td><td colspan='3' class='plugin-desc'>" + h.plugins[name].show_install_info() + "</td></tr>\n"
                 num += 1
             msg += "</table>\n"
-            msg += '<input type="submit" name="uninstall_hook" value="%s">\n' % _("Remove selected hooks")
+            msg += '<input type="submit" name="uninstall_hook" value="%s" class="input-button">\n' % _("Remove selected hooks")
 
         return msg
     
@@ -167,11 +170,20 @@ class ReposController(BaseController):
             plugin = h.plugins[pluginname]
             plugin.install(d)
         except Exception, e:
-            result = "<div class='error'>" + _("Apply plugin '%(plugin)s' on '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
-                        "plugin": pluginname, "repos":reposname, "msg": to_unicode(e) } + "</div>"
+            result = json.dumps( {
+                    "type": "error",
+                    "message": _("Apply plugin '%(plugin)s' on '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
+                          "plugin": pluginname,
+                          "repos":reposname,
+                          "msg": to_unicode(e) }
+                    } )
         else:
-            result = "<div class='info'>" + _("Apply plugin '%(plugin)s' on '%(repos)s' success.") % {
-                        "plugin": pluginname, "repos":reposname} + "</div>"
+            result = json.dumps( {
+                    "type": "info",
+                    "message": _("Apply plugin '%(plugin)s' on '%(repos)s' success.") % {
+                          "plugin": pluginname,
+                          "repos":reposname }
+                    } )
         return result
     
     def uninstall_hook(self):
@@ -192,13 +204,25 @@ class ReposController(BaseController):
                     hookobj.plugins[pluginname].uninstall()
                     log.info("my delete plugin %s, %s" % (pluginname, hookobj.plugins[pluginname].name))
             except Exception, e:
-                result = "<div class='error'>" + _("Delete plugin '%(plugin)s' on '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
-                        "plugin": ", ".join(plugin_list), "repos":reposname, "msg": to_unicode(e) } + "</div>"
+                result = json.dumps( {
+                        "type": "error",
+                        "message": _("Delete plugin '%(plugin)s' on '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
+                                "plugin": ", ".join(plugin_list),
+                                "repos":reposname,
+                                "msg": to_unicode(e) }
+                        } )
             else:
-                result = "<div class='info'>" + _("Delete plugin '%(plugin)s' on '%(repos)s' success.") % {
-                        "plugin": ", ".join(plugin_list), "repos":reposname} + "</div>"
+                result = json.dumps( {
+                        "type": "info",
+                        "message": _("Delete plugin '%(plugin)s' on '%(repos)s' success.") % {
+                                "plugin": ", ".join(plugin_list),
+                                "repos":reposname }
+                        } )
         else:
-            result = "<div class='error'>" + _("No plugin has been deleted for '%(repos)s'.") % {"repos":reposname} + "</div>"
+            result = json.dumps( {
+                    "type": "error",
+                    "message": _("No plugin has been deleted for '%(repos)s'.") % {"repos":reposname}
+                    } )
         return result
 
     def create_submit(self):
@@ -208,10 +232,16 @@ class ReposController(BaseController):
             self.validate_repos(reposname)
             self.repos.create(reposname)
         except Exception, e:
-            result = "<div class='error'>" + _("Create repository '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
-                        "repos":reposname, "msg": to_unicode(e) } + "</div>"
+            result = json.dumps( {
+                    "type": "error",
+                    "message": _("Create repository '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
+                            "repos":reposname, "msg": to_unicode(e) }
+                    } )
         else:
-            result = "<div class='info'>" + _("Create repository '%(repos)s' success.") % {"repos":reposname} + "</div>"
+            result = json.dumps( {
+                    "type": "info",
+                    "message": _("Create repository '%(repos)s' success.") % {"repos":reposname} 
+                    } )
         return result
         
     def create(self):
@@ -227,13 +257,22 @@ class ReposController(BaseController):
             self.validate_repos(reposname)
             self.repos.delete(reposname)
         except Exception, e:
-            result = "<div class='error'>" + _("Delete repository '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
-                        "repos":reposname, "msg": to_unicode(e) } + "</div>"
+            result = json.dumps( {
+                    "type": "error",
+                    "message": _("Delete repository '%(repos)s' Failed. Error message:<br>\n%(msg)s") % {
+                            "repos":reposname, "msg": to_unicode(e) }
+                    } )
         else:
-            result = "<div class='info'>" + _("Delete blank repository '%(repos)s' success.") % {"repos":reposname} + "</div>"
+            result = json.dumps( {
+                    "type": "info",
+                    "message": _("Delete blank repository '%(repos)s' success.") % {"repos":reposname}
+                    } )
         return result
     
     def remove(self):
         if not self.is_super_user:
             return redirect(url(controller='security', action='failed'))
         return render('/repos/remove.mako')
+
+
+# vim: et ts=4 sw=4
