@@ -40,7 +40,7 @@ from pysvnmanager.hooks import plugins
 from pysvnmanager.model import repos
 
 # i18n works only as pysvnmanager (a pylons app) model.
-if config.get('package') and not config.has_key('unittest'):
+if not config.has_key('unittest'):
     from pylons.i18n import _
 else:
     def _(message): return message
